==> pegasus-service-purchase-1.0-sources.jar: com/thebeastshop/pegasus/service/purchase/vo/PrdcRecipeMaterialVO.java <==
/**
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.service.purchase.vo;

/**
 * @author Eric.Lou
 * @version $Id: PrdcRecipeMaterialVO.java, v 0.1 2015-12-30 下午5:41
 */
public class PrdcRecipeMaterialVO {

    // constructor
    public PrdcRecipeMaterialVO(){

    }

    // original
    private Long id;

    private Long recipeId;

    private String skuCode;

    private Float quantity;

    private Integer materialType;

    // self
    private String skuName;

    private String categoryName;

    private String secondCategoryName;

    private String categoryFullName;

    private String warehouseCode;
    //可用库存
    private int availableAmount;

    // manual generate

    // auto generate
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getRecipeId() {
        return recipeId;
    }

    public void setRecipeId(Long recipeId) {
        this.recipeId = recipeId;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Float getQuantity() {
        return quantity;
    }

    public void setQuantity(Float quantity) {
        this.quantity = quantity;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public String getSecondCategoryName() {
        return secondCategoryName;
    }

    public void setSecondCategoryName(String secondCategoryName) {
        this.secondCategoryName = secondCategoryName;
    }

    public String getCategoryFullName() {
        return categoryFullName;
    }

    public void setCategoryFullName(String categoryFullName) {
        this.categoryFullName = categoryFullName;
    }

    public Integer getMaterialType() {
        return materialType;
    }

    public void setMaterialType(Integer materialType) {
        this.materialType = materialType;
    }

    public int getAvailableAmount() {
        return availableAmount;
    }

    public void setAvailableAmount(int availableAmount) {
        this.availableAmount = availableAmount;
    }

    public String getWarehouseCode() {
        return warehouseCode;
    }

    public void setWarehouseCode(String warehouseCode) {
        this.warehouseCode = warehouseCode;
    }
}

==> pegasus-service-purchase-2.0.8-sources.jar: com/thebeastshop/pegasus/service/purchase/vo/PrdcRecipeMaterialVO.java <==
/**
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.service.purchase.vo;

/**
 * @author Eric.Lou
 * @version $Id: PrdcRecipeMaterialVO.java, v 0.1 2015-12-30 下午5:41
 */
public class PrdcRecipeMaterialVO {

    // constructor
    public PrdcRecipeMaterialVO(){

    }

    // original
    private Long id;

    private Long recipeId;

    private String skuCode;

    private Float quantity;

    private Integer materialType;
    // 主耗材
    public static Integer MATERIAL_TYPE_MAIN = 1;
    // 辅耗材
    public static Integer MATERIAL_TYPE_ASSIST = 2;

    // self
    private String skuName;

    private String categoryName;

    private String secondCategoryName;

    private String categoryFullName;

    private String warehouseCode;
    private String physicalWarehouseCode;
    //可用库存
    private int availableAmount;

    // 物理仓可用库存
    private int physicalAvailableAmount;

    // manual generate

    // auto generate
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getRecipeId() {
        return recipeId;
    }

    public void setRecipeId(Long recipeId) {
        this.recipeId = recipeId;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Float getQuantity() {
        return quantity;
    }

    public void setQuantity(Float quantity) {
        this.quantity = quantity;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public String getSecondCategoryName() {
        return secondCategoryName;
    }

    public void setSecondCategoryName(String secondCategoryName) {
        this.secondCategoryName = secondCategoryName;
    }

    public String getCategoryFullName() {
        return categoryFullName;
    }

    public void setCategoryFullName(String categoryFullName) {
        this.categoryFullName = categoryFullName;
    }

    public Integer getMaterialType() {
        return materialType;
    }

    public void setMaterialType(Integer materialType) {
        this.materialType = materialType;
    }

    public int getAvailableAmount() {
        return availableAmount;
    }

    public void setAvailableAmount(int availableAmount) {
        this.availableAmount = availableAmount;
    }

    public String getWarehouseCode() {
        return warehouseCode;
    }

    public void setWarehouseCode(String warehouseCode) {
        this.warehouseCode = warehouseCode;
    }

    public String getPhysicalWarehouseCode() {
        return physicalWarehouseCode;
    }

    public void setPhysicalWarehouseCode(String physicalWarehouseCode) {
        this.physicalWarehouseCode = physicalWarehouseCode;
    }

    public int getPhysicalAvailableAmount() {
        return physicalAvailableAmount;
    }

    public void setPhysicalAvailableAmount(int physicalAvailableAmount) {
        this.physicalAvailableAmount = physicalAvailableAmount;
    }
}
